@@ -61,10 +61,16 @@ from tests.conjecture.common import interesting_origin
 
 T = TypeVar("T")
 
-pytestmark = pytest.mark.skipif(
-    settings._current_profile == "crosshair",
-    reason="using internals for testing in a way crosshair doesn't support",
-)
+pytestmark = [
+    pytest.mark.skipif(
+        settings.get_current_profile_name() == "crosshair",
+        reason="using internals for testing in a way crosshair doesn't support",
+    ),
+    pytest.mark.skipif(
+        settings.get_current_profile_name() == "threading",
+        reason="not worth making thread-safe atm",
+    ),
+]
 
 
 def safe_draw(data, strategy):
